@@ -1,5 +1,10 @@
 package Dancer2::Plugin::Swagger2;
+
+use strict;
+use warnings;
+
 # ABSTRACT: A Dancer2 plugin for creating routes from a Swagger2 spec
+our $VERSION = '0.003'; # VERSION
 
 use Dancer2 ':syntax';
 use Dancer2::Plugin;
@@ -7,8 +12,6 @@ use Module::Load;
 use Swagger2;
 use Swagger2::SchemaValidator;
 
-our $VERSION = '0.002_002';    # TRIAL VERSION
-
 
 sub DEBUG { !!$ENV{SWAGGER2_DEBUG} }
 
@@ -35,17 +38,19 @@ register swagger2 => sub {
       : exists $conf->{validate_responses} ? !!$conf->{validate_responses}
       :                                      $validate_spec;
 
-    if ( ( $validate_requests or $validate_responses ) and not $validate_spec )
-    {
-        die "Cannot validate requests/responses with spec assured to be true";
-    }
-
     # parse Swagger2 file
     my $spec = Swagger2->new($url)->expand;
 
-    if ($validate_spec) {
-        my @errors = $spec->validate;
-        @errors and die join "\n" => "Swagger2: Invalid spec:", @errors;
+    if ( $validate_spec or $validate_requests or $validate_responses ) {
+        if ( my @errors = $spec->validate ) {
+            if ($validate_spec) {
+                die join "\n" => "Swagger2: Invalid spec:", @errors;
+            }
+            else {
+                warn "Spec contains errors but"
+                  . " request/response validation is enabled!";
+            }
+        }
     }
 
     my $basePath = $spec->api_spec->get('/basePath');
@@ -296,7 +301,7 @@ Dancer2::Plugin::Swagger2 - A Dancer2 plugin for creating routes from a Swagger2
 
 =head1 VERSION
 
-version 0.002_002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -306,8 +311,9 @@ C<example/my_app.pl>:
 
     use Dancer2;
     use Dancer2::Plugin::Swagger2;
+    use Path::Tiny;
 
-    swagger2( url => path( dirname(__FILE__), 'swagger2.yaml' ) );
+    swagger2( url => path(__FILE__)->parent->child('swagger2.yaml') );
 
     sub my_controller {
         return "Hello World!\n";
@@ -360,15 +366,15 @@ Import routes from Swagger file. Named arguments:
 
 =over
 
-=item C<url>: URL to passed to L<Swagger2> module
+=item * C<url>: URL to passed to L<Swagger2> module
 
-=item C<controller_factory>: custom callback generator/finder that returns callbacks to routes
+=item * C<controller_factory>: custom callback generator/finder that returns callbacks to routes
 
-=item C<validate_spec>: boolish value (default: true) telling if Swagger2 file shall be validated by official Swagger specification
+=item * C<validate_spec>: boolish value (default: true) telling if Swagger2 file shall be validated by official Swagger specification
 
-=item C<validate_requests>: boolish value (default: same as C<validate_spec>) telling if HTTP requests shall be validated by loaded specification (needs C<validate_spec> to be true)
+=item * C<validate_requests>: boolish value (default: same as C<validate_spec>) telling if HTTP requests shall be validated by loaded specification (needs C<validate_spec> to be true)
 
-=item C<validate_responses>: boolish value (default: same as C<validate_spec>) telling if HTTP responses shall be validated by loaded specification (needs C<validate_spec> to be true)
+=item * C<validate_responses>: boolish value (default: same as C<validate_spec>) telling if HTTP responses shall be validated by loaded specification (needs C<validate_spec> to be true)
 
 =back
 
@@ -385,6 +391,16 @@ mentioned above and as a top level module name.
 The module warns as long as controller modules or methods can't be found
 and returns a coderef on the first match.
 
+=head1 SEE ALSO
+
+=over
+
+=item * L<Mojolicious::Plugin::Swagger2> A similar plugin for the L<Mojolicious> Web framework
+
+=item * L<http://swagger.io/>: Website of the Swagger alias OpenAPI Specification
+
+=back
+
 =head1 ACKNOWLEDGEMENT
 
 This software has been developed with support from L<STRATO|https://www.strato.com/>.
